@@ -1,7 +1,7 @@
 package App::EPAN;
 
 use 5.012;
-{ our $VERSION = '0.001' }
+{ our $VERSION = '0.001001' }
 use warnings;
 use English qw( -no_match_vars );
 use version;
@@ -156,9 +156,7 @@ sub _do_index {
       $basedir->file(qw< modules 02packages.details.txt.gz >)    # default
    );
 
-   $self->_save(
-      '03modlist.data',                                          # name
-      <<'END_OF_03_MODLIST_DATA',
+   my $_03modlist_data_1 = <<'END_OF_03_MODLIST_DATA_1';
 File:        03modlist.data
 Description: These are the data that are published in the module
         list, but they may be more recent than the latest posted
@@ -169,7 +167,10 @@ Modcount:    0
 Written-By:  PAUSE version 1.005
 Date:        Sun, 28 Jul 2013 07:41:15 GMT
 
-package CPAN::Modulelist;
+pac
+END_OF_03_MODLIST_DATA_1
+   my $_03modlist_data_2 = <<'END_OF_03_MODLIST_DATA_2';
+kage CPAN::Modulelist;
 # Usage: print Data::Dumper->new([CPAN::Modulelist->data])->Dump or similar
 # cannot 'use strict', because we normally run under Safe
 # use strict;
@@ -185,7 +186,13 @@ sub data {
 }
 $CPAN::Modulelist::cols = [ ];
 $CPAN::Modulelist::data = [ ];
-END_OF_03_MODLIST_DATA
+END_OF_03_MODLIST_DATA_2
+
+   $_03modlist_data_1 =~ s{\s+\z}{}mxs;
+   $_03modlist_data_2 =~ s{\A\s+}{}mxs;
+   $self->_save(
+      '03modlist.data',                                          # name
+      "$_03modlist_data_1$_03modlist_data_2",
       'modlist',    # configuration key to look output file
       $basedir->file(qw< modules 03modlist.data.gz >)    # default
    );
